@@ -1,22 +1,31 @@
 import great_expectations.exceptions as ge_exceptions
+from great_expectations.data_context.store.store_backend import StoreBackend
 
 try:
     import sqlalchemy
-    from sqlalchemy import create_engine, Column, String, MetaData, Table, select, and_, column
+    from sqlalchemy import (
+        create_engine,
+        Column,
+        String,
+        MetaData,
+        Table,
+        select,
+        and_,
+        column,
+    )
     from sqlalchemy.engine.url import URL
 except ImportError:
     sqlalchemy = None
     create_engine = None
 
-from great_expectations.data_context.store.store_backend import StoreBackend
-
 
 class DatabaseStoreBackend(StoreBackend):
-
     def __init__(self, credentials, table_name, key_columns, fixed_length_key=True):
         super().__init__(fixed_length_key=fixed_length_key)
         if not sqlalchemy:
-            raise ge_exceptions.DataContextError("ModuleNotFoundError: No module named 'sqlalchemy'")
+            raise ge_exceptions.DataContextError(
+                "ModuleNotFoundError: No module named 'sqlalchemy'"
+            )
 
         if not self.fixed_length_key:
             raise ValueError("DatabaseStoreBackend requires use of a fixed-length-key")
@@ -31,10 +40,7 @@ class DatabaseStoreBackend(StoreBackend):
             cols.append(Column(column, String, primary_key=True))
 
         cols.append(Column("value", String))
-        self._table = Table(
-            table_name, meta,
-            *cols
-        )
+        self._table = Table(table_name, meta, *cols)
 
         drivername = credentials.pop("drivername")
         options = URL(drivername, **credentials)
@@ -42,9 +48,16 @@ class DatabaseStoreBackend(StoreBackend):
         meta.create_all(self.engine)
 
     def _get(self, key):
-        sel = select([column("value")]).select_from(self._table).where(
-            and_(
-                *[getattr(self._table.columns, key_col) == val for key_col, val in zip(self.key_columns, key)]
+        sel = (
+            select([column("value")])
+            .select_from(self._table)
+            .where(
+                and_(
+                    *[
+                        getattr(self._table.columns, key_col) == val
+                        for key_col, val in zip(self.key_columns, key)
+                    ]
+                )
             )
         )
         res = self.engine.execute(sel).fetchone()
@@ -61,10 +74,19 @@ class DatabaseStoreBackend(StoreBackend):
         pass
 
     def list_keys(self, prefix=()):
-        sel = select([column(col) for col in self.key_columns]).select_from(self._table).where(
-            and_(
-                *[getattr(self._table.columns, key_col) == val for key_col, val in
-                  zip(self.key_columns[:len(prefix)], prefix)]
+        sel = (
+            select([column(col) for col in self.key_columns])
+            .select_from(self._table)
+            .where(
+                and_(
+                    *[
+                        getattr(self._table.columns, key_col) == val
+                        for key_col, val in zip(self.key_columns[: len(prefix)], prefix)
+                    ]
+                )
             )
         )
         return [tuple(row) for row in self.engine.execute(sel).fetchall()]
+
+    def remove_key(self, key):
+        raise NotImplementedError
