@@ -1,24 +1,18 @@
 import datetime
-import uuid
 import logging
+import uuid
 from functools import partial
-
-from ..types.configurations import classConfigSchema
-
-try:
-    from io import StringIO
-except ImportError:
-    from StringIO import StringIO
-
-from six import PY2
+from io import StringIO
 
 import pandas as pd
 
-from .datasource import Datasource
-from great_expectations.datasource.types import BatchMarkers
 from great_expectations.core.batch import Batch
-from great_expectations.types import ClassConfig
+from great_expectations.datasource.types import BatchMarkers
 from great_expectations.exceptions import BatchKwargsError
+from great_expectations.types import ClassConfig
+
+from ..types.configurations import classConfigSchema
+from .datasource import Datasource
 from .util import S3Url, hash_pandas_dataframe
 
 logger = logging.getLogger(__name__)
@@ -31,11 +25,25 @@ class PandasDatasource(Datasource):
     interacting with the local filesystem (the default subdir_reader generator), and from
     existing in-memory dataframes.
     """
-    recognized_batch_parameters = {'reader_method', 'reader_options', 'limit', 'dataset_options'}
+
+    recognized_batch_parameters = {
+        "reader_method",
+        "reader_options",
+        "limit",
+        "dataset_options",
+    }
 
     @classmethod
-    def build_configuration(cls, data_asset_type=None, batch_kwargs_generators=None, boto3_options=None, reader_method=None,
-                            reader_options=None, limit=None, **kwargs):
+    def build_configuration(
+        cls,
+        data_asset_type=None,
+        batch_kwargs_generators=None,
+        boto3_options=None,
+        reader_method=None,
+        reader_options=None,
+        limit=None,
+        **kwargs
+    ):
         """
         Build a full configuration object for a datasource, potentially including generators with defaults.
 
@@ -56,7 +64,7 @@ class PandasDatasource(Datasource):
         if data_asset_type is None:
             data_asset_type = {
                 "class_name": "PandasDataset",
-                "module_name": "great_expectations.dataset"
+                "module_name": "great_expectations.dataset",
             }
         else:
             data_asset_type = classConfigSchema.dump(ClassConfig(**data_asset_type))
@@ -70,15 +78,19 @@ class PandasDatasource(Datasource):
             if isinstance(boto3_options, dict):
                 configuration.update(boto3_options)
             else:
-                raise ValueError("boto3_options must be a dictionary of key-value pairs to pass to boto3 upon "
-                                 "initialization.")
+                raise ValueError(
+                    "boto3_options must be a dictionary of key-value pairs to pass to boto3 upon "
+                    "initialization."
+                )
 
         if reader_options is not None:
             if isinstance(reader_options, dict):
                 configuration.update(reader_options)
             else:
-                raise ValueError("boto3_options must be a dictionary of key-value pairs to pass to boto3 upon "
-                                 "initialization.")
+                raise ValueError(
+                    "boto3_options must be a dictionary of key-value pairs to pass to boto3 upon "
+                    "initialization."
+                )
 
         if reader_method is not None:
             configuration["reader_method"] = reader_method
@@ -88,22 +100,39 @@ class PandasDatasource(Datasource):
 
         return configuration
 
-    def __init__(self, name="pandas", data_context=None, data_asset_type=None, batch_kwargs_generators=None,
-                 boto3_options=None, reader_method=None, reader_options=None, limit=None, **kwargs):
-        configuration_with_defaults = PandasDatasource.build_configuration(data_asset_type, batch_kwargs_generators,
-                                                                           boto3_options,
-                                                                           reader_method=reader_method,
-                                                                           reader_options=reader_options,
-                                                                           limit=limit,
-                                                                           **kwargs)
+    def __init__(
+        self,
+        name="pandas",
+        data_context=None,
+        data_asset_type=None,
+        batch_kwargs_generators=None,
+        boto3_options=None,
+        reader_method=None,
+        reader_options=None,
+        limit=None,
+        **kwargs
+    ):
+        configuration_with_defaults = PandasDatasource.build_configuration(
+            data_asset_type,
+            batch_kwargs_generators,
+            boto3_options,
+            reader_method=reader_method,
+            reader_options=reader_options,
+            limit=limit,
+            **kwargs
+        )
 
         data_asset_type = configuration_with_defaults.pop("data_asset_type")
-        batch_kwargs_generators = configuration_with_defaults.pop("batch_kwargs_generators", None)
-        super(PandasDatasource, self).__init__(name,
-                                               data_context=data_context,
-                                               data_asset_type=data_asset_type,
-                                               batch_kwargs_generators=batch_kwargs_generators,
-                                               **configuration_with_defaults)
+        batch_kwargs_generators = configuration_with_defaults.pop(
+            "batch_kwargs_generators", None
+        )
+        super(PandasDatasource, self).__init__(
+            name,
+            data_context=data_context,
+            data_asset_type=data_asset_type,
+            batch_kwargs_generators=batch_kwargs_generators,
+            **configuration_with_defaults
+        )
 
         self._build_generators()
         self._boto3_options = configuration_with_defaults.get("boto3_options", {})
@@ -111,14 +140,13 @@ class PandasDatasource(Datasource):
         self._reader_options = configuration_with_defaults.get("reader_options", None)
         self._limit = configuration_with_defaults.get("limit", None)
 
-    def process_batch_parameters(self,
-                                 reader_method=None,
-                                 reader_options=None,
-                                 limit=None,
-                                 dataset_options=None,
-                                 ):
+    def process_batch_parameters(
+        self, reader_method=None, reader_options=None, limit=None, dataset_options=None,
+    ):
         # Note that we do not pass limit up, since even that will be handled by PandasDatasource
-        batch_kwargs = super(PandasDatasource, self).process_batch_parameters(dataset_options=dataset_options)
+        batch_kwargs = super(PandasDatasource, self).process_batch_parameters(
+            dataset_options=dataset_options
+        )
 
         # Apply globally-configured reader options first
         if self._reader_options:
@@ -136,12 +164,12 @@ class PandasDatasource(Datasource):
         if self._limit:
             if not batch_kwargs.get("reader_options"):
                 batch_kwargs["reader_options"] = dict()
-            batch_kwargs['reader_options']['nrows'] = self._limit
+            batch_kwargs["reader_options"]["nrows"] = self._limit
 
         if limit is not None:
             if not batch_kwargs.get("reader_options"):
                 batch_kwargs["reader_options"] = dict()
-            batch_kwargs['reader_options']['nrows'] = limit
+            batch_kwargs["reader_options"]["nrows"] = limit
 
         if self._reader_method:
             batch_kwargs["reader_method"] = self._reader_method
@@ -152,21 +180,16 @@ class PandasDatasource(Datasource):
         return batch_kwargs
 
     def get_batch(self, batch_kwargs, batch_parameters=None):
-        # pandas cannot take unicode as a delimiter, which can happen in py2. Handle this case explicitly.
-        # We handle it here so that the updated value will be in the batch_kwargs for transparency to the user.
-        if PY2 and "reader_options" in batch_kwargs and "sep" in batch_kwargs['reader_options'] and \
-                batch_kwargs['reader_options']['sep'] is not None:
-            batch_kwargs['reader_options']['sep'] = str(batch_kwargs['reader_options']['sep'])
         # We will use and manipulate reader_options along the way
         reader_options = batch_kwargs.get("reader_options", {})
 
         # We need to build a batch_markers to be used in the dataframe
-        batch_markers = BatchMarkers({
-            "ge_load_time": datetime.datetime.utcnow().strftime("%Y%m%dT%H%M%S.%fZ")
-        })
+        batch_markers = BatchMarkers(
+            {"ge_load_time": datetime.datetime.utcnow().strftime("%Y%m%dT%H%M%S.%fZ")}
+        )
 
         if "path" in batch_kwargs:
-            path = batch_kwargs['path']
+            path = batch_kwargs["path"]
             reader_method = batch_kwargs.get("reader_method")
             reader_fn = self._get_reader_fn(reader_method, path)
             df = reader_fn(path, **reader_options)
@@ -174,30 +197,43 @@ class PandasDatasource(Datasource):
         elif "s3" in batch_kwargs:
             try:
                 import boto3
+
                 s3 = boto3.client("s3", **self._boto3_options)
             except ImportError:
-                raise BatchKwargsError("Unable to load boto3 client to read s3 asset.", batch_kwargs)
+                raise BatchKwargsError(
+                    "Unable to load boto3 client to read s3 asset.", batch_kwargs
+                )
             raw_url = batch_kwargs["s3"]
             reader_method = batch_kwargs.get("reader_method")
             url = S3Url(raw_url)
-            logger.debug("Fetching s3 object. Bucket: %s Key: %s" % (url.bucket, url.key))
+            logger.debug(
+                "Fetching s3 object. Bucket: %s Key: %s" % (url.bucket, url.key)
+            )
             s3_object = s3.get_object(Bucket=url.bucket, Key=url.key)
             reader_fn = self._get_reader_fn(reader_method, url.key)
             df = reader_fn(
-                StringIO(s3_object["Body"].read().decode(s3_object.get("ContentEncoding", "utf-8"))),
+                StringIO(
+                    s3_object["Body"]
+                    .read()
+                    .decode(s3_object.get("ContentEncoding", "utf-8"))
+                ),
                 **reader_options
             )
 
-        elif "dataset" in batch_kwargs and isinstance(batch_kwargs["dataset"], (pd.DataFrame, pd.Series)):
+        elif "dataset" in batch_kwargs and isinstance(
+            batch_kwargs["dataset"], (pd.DataFrame, pd.Series)
+        ):
             df = batch_kwargs.get("dataset")
             # We don't want to store the actual dataframe in kwargs; copy the remaining batch_kwargs
-            batch_kwargs = {k: batch_kwargs[k] for k in batch_kwargs if k != 'dataset'}
+            batch_kwargs = {k: batch_kwargs[k] for k in batch_kwargs if k != "dataset"}
             batch_kwargs["PandasInMemoryDF"] = True
             batch_kwargs["ge_batch_id"] = str(uuid.uuid1())
 
         else:
-            raise BatchKwargsError("Invalid batch_kwargs: path, s3, or df is required for a PandasDatasource",
-                                   batch_kwargs)
+            raise BatchKwargsError(
+                "Invalid batch_kwargs: path, s3, or df is required for a PandasDatasource",
+                batch_kwargs,
+            )
 
         if df.memory_usage().sum() < HASH_THRESHOLD:
             batch_markers["pandas_data_fingerprint"] = hash_pandas_dataframe(df)
@@ -208,7 +244,7 @@ class PandasDatasource(Datasource):
             data=df,
             batch_parameters=batch_parameters,
             batch_markers=batch_markers,
-            data_context=self._data_context
+            data_context=self._data_context,
         )
 
     @staticmethod
@@ -224,9 +260,14 @@ class PandasDatasource(Datasource):
         elif path.endswith(".pkl"):
             return {"reader_method": "read_pickle"}
         elif path.endswith(".csv.gz") or path.endswith(".csv.gz"):
-            return {"reader_method": "read_csv", "reader_options": {"compression": "gzip"}}
+            return {
+                "reader_method": "read_csv",
+                "reader_options": {"compression": "gzip"},
+            }
 
-        raise BatchKwargsError("Unable to determine reader method from path: %s" % path, {"path": path})
+        raise BatchKwargsError(
+            "Unable to determine reader method from path: %s" % path, {"path": path}
+        )
 
     def _get_reader_fn(self, reader_method=None, path=None):
         """Static helper for parsing reader types. If reader_method is not provided, path will be used to guess the
@@ -241,14 +282,18 @@ class PandasDatasource(Datasource):
 
         """
         if reader_method is None and path is None:
-            raise BatchKwargsError("Unable to determine pandas reader function without reader_method or path.",
-                                   {"reader_method": reader_method})
+            raise BatchKwargsError(
+                "Unable to determine pandas reader function without reader_method or path.",
+                {"reader_method": reader_method},
+            )
 
         reader_options = None
         if reader_method is None:
             path_guess = self.guess_reader_method_from_path(path)
             reader_method = path_guess["reader_method"]
-            reader_options = path_guess.get("reader_options")  # This may not be there; use None in that case
+            reader_options = path_guess.get(
+                "reader_options"
+            )  # This may not be there; use None in that case
 
         try:
             reader_fn = getattr(pd, reader_method)
@@ -256,5 +301,7 @@ class PandasDatasource(Datasource):
                 reader_fn = partial(reader_fn, **reader_options)
             return reader_fn
         except AttributeError:
-            raise BatchKwargsError("Unable to find reader_method %s in pandas." % reader_method, {"reader_method":
-                                                                                                      reader_method})
+            raise BatchKwargsError(
+                "Unable to find reader_method %s in pandas." % reader_method,
+                {"reader_method": reader_method},
+            )
