@@ -20,8 +20,7 @@ class SuiteScaffoldNotebookRenderer(SuiteEditNotebookRenderer):
     def add_header(self):
         self.add_markdown_cell(
             """# Scaffold a new Expectation Suite (BETA)
-Use this notebook to scaffold a new expectations suite. This process helps you
-avoid writing lots of boilerplate when authoring suites.
+This process helps you avoid writing lots of boilerplate when authoring suites by allowing you to select columns you care about and letting a profiler write some candidate expectations for you to adjust.
 
 **Expectation Suite Name**: `{}`
 
@@ -66,7 +65,7 @@ included_columns = [
         self.add_markdown_cell(
             """## Save & review the scaffolded Expectation Suite
 
-Let's save the scaffolded expectation suite as a JSON file in the 
+Let's save the scaffolded expectation suite as a JSON file in the
 `great_expectations/expectations` directory of your project and rebuild the Data
  Docs site to make reviewing the scaffolded suite easy."""
         )
@@ -89,8 +88,8 @@ context.open_data_docs(validation_result_identifier)"""
         )
         self.add_markdown_cell(
             f"""## Next steps
-After you are happy with this scaffolded Expectation Suite in Data Docs you 
-should edit this suite to make finer grained adjustments to the expectations. 
+After you are happy with this scaffolded Expectation Suite in Data Docs you
+should edit this suite to make finer grained adjustments to the expectations.
 This is be done by running `great_expectations suite edit {self.suite_name}`."""
         )
 
@@ -105,8 +104,9 @@ This is be done by running `great_expectations suite edit {self.suite_name}`."""
         self._notebook = nbformat.v4.new_notebook()
         self.add_header()
         self.add_markdown_cell(
-            """\
-## Select the columns you want to scaffold expectations on
+            """## Select the columns you want to scaffold expectations on
+
+Great Expectations will choose which expectations might make sense for a column based on the **data type** and **cardinality** of the data in each selected column.
 
 Simply uncomment columns that are important. You can select multiple lines and
 use a jupyter keyboard shortcut to toggle each line: **Linux/Windows**:
@@ -117,17 +117,16 @@ use a jupyter keyboard shortcut to toggle each line: **Linux/Windows**:
         self.add_markdown_cell(
             """## Run the scaffolder
 
+The suites generated here are **not meant to be production suites** - they are **scaffolds to build upon**.
+
+**To get to a production grade suite, will definitely want to [edit this
+suite](http://docs.greatexpectations.io/en/latest/command_line.html#great-expectations-suite-edit)
+after scaffolding gets you close to what you want.**
+
 This is highly configurable depending on your goals. You can include or exclude
-columns, and include or exclude expectation types (when applicable). [The 
-Expectation Glossary](http://docs.greatexpectations.io/en/latest/expectation_glossary.html) 
-contains a list of possible expectations.
-
-Note that the profiler is not very smart, so it does it's best to decide on
-applicability.
-
-**To get to a production grade suite, you should [edit this 
-suite](http://docs.greatexpectations.io/en/latest/command_line.html#great-expectations-suite-edit) 
-after this scaffold gets you close to what you want.**"""
+columns, and include or exclude expectation types (when applicable). [The
+Expectation Glossary](http://docs.greatexpectations.io/en/latest/expectation_glossary.html)
+contains a list of possible expectations."""
         )
         self._add_scaffold_cell()
         self.add_footer()
@@ -156,6 +155,5 @@ scaffold_config = {
     # "included_expectations": [],
     # "excluded_expectations": [],
 }
-suite, evr = BasicSuiteBuilderProfiler().profile(batch, profiler_configuration=scaffold_config)""",
-            lint=False,
+suite, evr = BasicSuiteBuilderProfiler().profile(batch, profiler_configuration=scaffold_config)"""
         )
